:github_url: https://github.com/gjeusel/ticts

Welcome to ticts's documentation!
==================================================

A Python library for unevenly-spaced time series analysis

.. toctree::
   :maxdepth: 2
   :caption: Notes

   quickstart <notes/quickstart>


.. toctree::
   :maxdepth: 2
   :caption: Package Reference

   ticts.cli <src/cli>


.. toctree::
   :maxdepth: 1
   :caption: Miscellaneous

   authors
   changelog

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
